<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Log in met je Deepin ID.</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Log in om de vervolgstappen te kunnen volgen.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Je hebt teveel aanvragen gedaan - probeer het later opnieuw.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Log in om de vervolgstappen te kunnen volgen.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Netwerkfout; probeer het later opnieuw.</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Uitgelogd</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Mĳn favorieten</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mĳn feedback</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Uitloggen</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Inloggen</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 weergaven</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggesties</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Voorstellen</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Aankomend</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Officiële reactie</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Soort:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Bug</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggesties</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versie:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Sorteren op:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Nieuwste</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Voorstellen</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Communicatie</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discussieer mee en deel je ideeën</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Bugs</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Meld problemen waar je tegenaan loopt</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggesties</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Deel je suggesties</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Zelfstudies</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Vragenlĳst</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Doe mee</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Interne tests</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Globale vertaling</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Gemeenschapsnieuws</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Er zĳn geen items meer</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Berichten</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Vragenlĳsten</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Automatisch opstarten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Thuis</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Log in op het forum, deel ideeën en meld bugs.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Er zĳn nog geen berichten.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>Er zĳn %1 berichten</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Alles markeren als gelezen</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Meer berichten tonen</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Netwerkfout; probeer het later opnieuw</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Herladen</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Thuis</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Er zĳn nog geen vragenlĳsten.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Vervallen op %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Invullen</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>In afwachting</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Nabootsen</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestigd</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Beantwoord</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Opgelost</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>In behandeling</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Goedgekeurd</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Voltooid</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Dit probleem is nog niet verwerkt en wordt daarom niet openbaar getoond.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Het probleem kan momenteel niet worden vastgesteld. Er dient nader onderzoek te worden verricht.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Dit probleem is nagebootst en de oorzaak is vastgesteld.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Dit probleem is geen bug of iets dergelĳks.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Dit probleem is opgelost; de oplossing wordt binnenkort uitgerold.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>De vereiste is nog niet verwerkt en wordt daarom niet openbaar getoond.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Het probleem is vastgesteld; er wordt intern gewerkt aan een oplossing.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Gereed voor uitrol in een toekomstige versie.</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>De vereiste is niet goedgekeurd of kan niet worden opgelost.</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Gereed voor uitrol in een toekomstige versie.</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>De schermfoto kan niet worden toegevoegd.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>De afbeelding mag maximaal 1 MB groot zĳn.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Het bestandsformaat wordt niet ondersteund.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Huidige productstatus]: 
[Gewenst product]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Randvoorwaarden]: 
[Herleidbare stappen]: 
[Verwachte resultaten]: 
[Daadwerkelĳke resultaten]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Feedback versturen</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Soort:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggesties</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Bugmelding</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Omschrĳf je probleem</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Inhoud:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Let op: voer niet meerdere problemen in</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Let op: voer geen meerdere vereisten in</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-mailadres:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Voer je e-mailadres in</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Systeemversie:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Apparaatinformatie:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>&lt;a href=&apos;home://sysinfo&apos;&gt;Apparaatinformatie&lt;/a&gt; bĳvoegen</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Schermfoto&apos;s:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Afbeeldingsbestanden</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Sleep bestanden hierheen of klik op de knoppen (max. 3 afbeeldingen)</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Weet je zeker dat je je feedback niet wilt versturen?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>De inhoud ervan wordt niet opgeslagen.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Versturen</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>De feedback kan niet worden verstuurd.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Geef de feedback een naam en voorzie deze van inhoud.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Geef de feedback een naam.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Voorzie de feedback van inhoud.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Het e-mailadres is onjuist.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Apparaatinformatie</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Feedbackhub</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Mĳn feedback</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Mĳn favorieten</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Mĳn voorstellen</translation>
    </message>
</context>
</TS>